import defaultCountryCenter from "./defaultCountryCenter";

// Create leaflet map
function createMap(container, _ref) {
  var _window$L, _window$L$tileLayer, _window$L$tileLayer2, _window$L$tileLayer3, _window$L$tileLayer4, _window$L$tileLayer$c, _window$L$tileLayer5;
  var center = _ref.center,
    minZoom = _ref.minZoom,
    maxZoom = _ref.maxZoom,
    zoom = _ref.zoom;
  if (!window.L) {
    return '请在Map组件需要使用APILoader包裹';
  }
  if (!((_window$L = window.L) !== null && _window$L !== void 0 && (_window$L = _window$L.tileLayer) !== null && _window$L !== void 0 && _window$L.currentTileLayer)) {
    return '缺少必要地图资源, 请检查APILoader参数是否正确, 或者key是否过期';
  }

  // 百度地图最小3
  if (window.BMap && minZoom < 3) {
    // eslint-disable-next-line
    minZoom = 3;
  }
  var centerPoint = [];
  if (center !== null && center !== void 0 && center.latitude && center !== null && center !== void 0 && center.longitude) {
    centerPoint = [center === null || center === void 0 ? void 0 : center.latitude, center === null || center === void 0 ? void 0 : center.longitude];
  }
  // 中国默认天安门
  else if (window.BMap) {
    centerPoint = [defaultCountryCenter['zh_CN'].latitude, defaultCountryCenter['zh_CN'].longitude];
  }
  // 国外默认白宫
  else {
    centerPoint = [defaultCountryCenter['other'].latitude, defaultCountryCenter['other'].longitude];
  }
  // Init leaflet map config
  var config = {
    attributionControl: false,
    // 隐藏版权控件
    zoomControl: false,
    // 隐藏放大缩小控件
    maxZoom: maxZoom || ((_window$L$tileLayer = window.L.tileLayer) === null || _window$L$tileLayer === void 0 || (_window$L$tileLayer = _window$L$tileLayer.currentTileLayer) === null || _window$L$tileLayer === void 0 ? void 0 : _window$L$tileLayer.maxZoom) || 20,
    minZoom: minZoom || ((_window$L$tileLayer2 = window.L.tileLayer) === null || _window$L$tileLayer2 === void 0 || (_window$L$tileLayer2 = _window$L$tileLayer2.currentTileLayer) === null || _window$L$tileLayer2 === void 0 ? void 0 : _window$L$tileLayer2.minZoom) || 1,
    zoom: zoom || ((_window$L$tileLayer3 = window.L.tileLayer) === null || _window$L$tileLayer3 === void 0 || (_window$L$tileLayer3 = _window$L$tileLayer3.currentTileLayer) === null || _window$L$tileLayer3 === void 0 ? void 0 : _window$L$tileLayer3.zoom) || 13,
    center: centerPoint
  };

  // Init leaflet map config: crs
  if ((_window$L$tileLayer4 = window.L.tileLayer) !== null && _window$L$tileLayer4 !== void 0 && (_window$L$tileLayer4 = _window$L$tileLayer4.currentTileLayer) !== null && _window$L$tileLayer4 !== void 0 && _window$L$tileLayer4.crs) {
    config.crs = window.L.tileLayer.currentTileLayer.crs;
  }
  // Init leaflet map config: maxBounds
  if ((_window$L$tileLayer$c = window.L.tileLayer.currentTileLayer) !== null && _window$L$tileLayer$c !== void 0 && _window$L$tileLayer$c.maxBounds) {
    config.maxBounds = window.L.tileLayer.currentTileLayer.maxBounds;
  }

  // Leaflet map
  var map = window.L.map(container, config);

  // TileLayer error
  if (!((_window$L$tileLayer5 = window.L.tileLayer) !== null && _window$L$tileLayer5 !== void 0 && _window$L$tileLayer5.currentTileLayer)) {
    return map;
  }

  // Add tileLayer
  var tileLayer = window.L.tileLayer.currentTileLayer();
  tileLayer.addTo(map);

  // Update tileLayer size
  // map.invalidateSize()

  return new Promise(function (resolve) {
    tileLayer.on('load', function () {
      resolve(map);
    });
  });
}
export default createMap;